@@ -2,4 +2,4 @@ from .compose import compose
 from .split import split
 from .dictinglink import DictingLink
 from .shrink import ShrinkingLink
-from .context import SwitchAsyncLink, SwitchSyncLink
+from .context import SwitchAsyncLink
