@@ -125,9 +125,3 @@ class AsyncStatefulMockLink(AsyncTerminatingLink):
 
         else:
             raise NotImplementedError("Only subscription are mocked")
-
-    def query(self, operation: Operation) -> GraphQLResult:
-        raise NotImplementedError("This is a async Terminating Link")
-
-    def subscribe(self, operation: Operation) -> GraphQLResult:
-        raise NotImplementedError("This is a async Terminating Link")
